from distutils.core import setup


setup(
    name='hp_nester',
    version='1.0.0',
    py_modules=['nester'],
    author='How Peng',
    author_email='howpeng@foxmail.com',
    url='http://howpeng.com',
    description='A simple printer of nested lists.',
)